summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopetepicture.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopetepicture.h')
-rw-r--r--kopete/libkopete/kopetepicture.h40
1 files changed, 20 insertions, 20 deletions
diff --git a/kopete/libkopete/kopetepicture.h b/kopete/libkopete/kopetepicture.h
index 5631afc1..46e7a7c2 100644
--- a/kopete/libkopete/kopetepicture.h
+++ b/kopete/libkopete/kopetepicture.h
@@ -21,7 +21,7 @@
#include <ksharedptr.h>
#include "kopete_export.h"
-#include <qimage.h>
+#include <tqimage.h>
namespace KABC
{
@@ -33,12 +33,12 @@ namespace Kopete
/**
* @brief Represent a picture in Kopete context
*
* It kept a cache of a QImage object, a base64 string and
* a path to a image file. It ensure that all source are synced.
* Interally, the image is stored in PNG format when possible.
* It can happen that the image path do not return a PNG file.
*
* You can only use an QImage and a image path to create/update
* the picture.
* If the picture doesn't exist as a file, it generate a local
* copy into ~/.kde/share/apps/kopete/metacontactpicturecache
@@ -48,12 +48,12 @@ namespace Kopete
* How to use this class:
* @code
* Kopete::Picture picture;
- * picture.setPicture(QImage());
- * picture.setPicture(QString("/tmp/image.png"));
+ * picture.setPicture(TQImage());
+ * picture.setPicture(TQString("/tmp/image.png"));
*
- * QString base64 = picture.base64();
- * QString path = picture.path();
- * QImage image = picture.image();
+ * TQString base64 = picture.base64();
+ * TQString path = picture.path();
+ * TQImage image = picture.image();
* @endcode
*
* @author Michaƫl Larouche <michael.larouche@kdemail.net>
@@ -68,11 +68,11 @@ public:
/**
* Create a picture from a local path.
*/
- Picture(const QString &path);
+ Picture(const TQString &path);
/**
* Create a picture from a QImage.
*/
- Picture(const QImage &image);
+ Picture(const TQImage &image);
/**
* Create a picture from a KABC::Picture.
*/
@@ -92,21 +92,21 @@ public:
Picture &operator=(const Picture &other);
/**
* Return the current picture as QImage.
* QImage can used to draw the image on a context.
*
* @return the QImage cache of current picture.
*/
- QImage image();
+ TQImage image();
/**
* Return the current picture as a base64 string.
* The base64 is used to include the picture into a XML/XHTML context.
*/
- QString base64();
+ TQString base64();
/**
* Return the local path of the current picture.
*/
- QString path();
+ TQString path();
/**
* Check if the picture is null.
@@ -119,14 +119,14 @@ public:
/**
* Set the picture content.
* @param image the picture as a QImage.
*/
- void setPicture(const QImage &image);
+ void setPicture(const TQImage &image);
/**
* Set the picture content.
* @param path the path to the picture.
*/
- void setPicture(const QString &path);
+ void setPicture(const TQString &path);
/**
* Set the picture content.
* @param picture a KABC Picture.
@@ -33,12 +33,12 @@ namespace Kopete
* @brief Represent a picture in Kopete context
*
- * It kept a cache of a QImage object, a base64 string and
+ * It kept a cache of a TQImage object, a base64 string and
* a path to a image file. It ensure that all source are synced.
* Interally, the image is stored in PNG format when possible.
@@ -33,12 +33,12 @@ namespace Kopete
* It can happen that the image path do not return a PNG file.
*
- * You can only use an QImage and a image path to create/update
+ * You can only use an TQImage and a image path to create/update
* the picture.
* If the picture doesn't exist as a file, it generate a local
@@ -68,11 +68,11 @@ public:
/**
- * Create a picture from a QImage.
+ * Create a picture from a TQImage.
*/
@@ -92,21 +92,21 @@ public:
Picture &operator=(const Picture &other);
/**
- * Return the current picture as QImage.
- * QImage can used to draw the image on a context.
+ * Return the current picture as TQImage.
+ * TQImage can used to draw the image on a context.
*
@@ -92,21 +92,21 @@ public:
*
- * @return the QImage cache of current picture.
+ * @return the TQImage cache of current picture.
*/
@@ -119,14 +119,14 @@ public:
/**
* Set the picture content.
- * @param image the picture as a QImage.
+ * @param image the picture as a TQImage.
*/